@@ -65,7 +65,8 @@ enum
   PROP_AUTO_PACKET_SIZE,
   PROP_PACKET_RESEND,
   PROP_FEATURES,
-  PROP_NUM_ARV_BUFFERS
+  PROP_NUM_ARV_BUFFERS,
+  PROP_USB_MODE
 };
 
 #define GST_TYPE_ARV_AUTO (gst_arv_auto_get_type())
@@ -88,6 +89,26 @@ gst_arv_auto_get_type (void)
 	return arv_auto_type;
 }
 
+#define GST_TYPE_ARV_USB_MODE (gst_arv_usb_mode_get_type())
+static GType
+gst_arv_usb_mode_get_type (void)
+{
+	static GType arv_usb_mode_type = 0;
+
+	static const GEnumValue arv_usb_modes[] = {
+		{ARV_UV_USB_MODE_SYNC, "Synchronous", "sync"},
+		{ARV_UV_USB_MODE_ASYNC, "Asynchronous", "async"},
+		{ARV_UV_USB_MODE_DEFAULT, "Default", "default"},
+		{0, NULL, NULL},
+	};
+
+	if (!arv_usb_mode_type)
+	{
+		arv_usb_mode_type = g_enum_register_static("GstArvUsbMode", arv_usb_modes);
+	}
+	return arv_usb_mode_type;
+}
+
 G_DEFINE_TYPE (GstAravis, gst_aravis, GST_TYPE_PUSH_SRC);
 
 static GstStaticPadTemplate aravis_src_template = GST_STATIC_PAD_TEMPLATE ("src",
@@ -396,6 +417,7 @@ gst_aravis_init_camera (GstAravis *gst_aravis, GError **error)
 
 	if (!local_error) arv_camera_get_region (gst_aravis->camera, &gst_aravis->offset_x, &gst_aravis->offset_y, NULL, NULL, &local_error);
 	if (!local_error) gst_aravis->payload = 0;
+	if (!local_error) arv_camera_uv_set_usb_mode (gst_aravis->camera, gst_aravis->usb_mode);
 
 	if (local_error) {
 		g_clear_object (&gst_aravis->camera);
@@ -637,6 +659,7 @@ gst_aravis_init (GstAravis *gst_aravis)
         gst_aravis->packet_resend = TRUE;
 	gst_aravis->num_arv_buffers = GST_ARAVIS_DEFAULT_N_BUFFERS;
 	gst_aravis->payload = 0;
+	gst_aravis->usb_mode = ARV_UV_USB_MODE_DEFAULT;
 
 	gst_aravis->buffer_timeout_us = GST_ARAVIS_BUFFER_TIMEOUT_DEFAULT;
 
@@ -768,6 +791,9 @@ gst_aravis_set_property (GObject * object, guint prop_id,
 		case PROP_NUM_ARV_BUFFERS:
 			gst_aravis->num_arv_buffers = g_value_get_int (value);
 			break;
+		case PROP_USB_MODE:
+			gst_aravis->usb_mode = g_value_get_enum (value);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;
@@ -855,6 +881,9 @@ gst_aravis_get_property (GObject * object, guint prop_id, GValue * value,
 		case PROP_NUM_ARV_BUFFERS:
 			g_value_set_int (value, gst_aravis->num_arv_buffers);
 			break;
+		case PROP_USB_MODE:
+			g_value_set_enum(value, gst_aravis->usb_mode);
+			break;
 		default:
 			G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
 			break;
@@ -1003,6 +1032,14 @@ gst_aravis_class_init (GstAravisClass * klass)
 				   1, G_MAXINT, GST_ARAVIS_DEFAULT_N_BUFFERS,
 				   G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
 
+	g_object_class_install_property
+	    (gobject_class, PROP_USB_MODE,
+	     g_param_spec_enum("usb-mode",
+			       "USB mode",
+			       "USB mode (synchronous/asynchronous)",
+			       GST_TYPE_ARV_USB_MODE, ARV_UV_USB_MODE_DEFAULT,
+			       G_PARAM_READWRITE | G_PARAM_STATIC_STRINGS));
+
         GST_DEBUG_CATEGORY_INIT (aravis_debug, "aravissrc", 0, "Aravis interface");
 
 	gst_element_class_set_details_simple (element_class,
