@@ -28,10 +28,11 @@
 #endif
 
 #include <glib.h>
+#include <arvapi.h>
 
 G_BEGIN_DECLS
 
-gboolean		arv_debug_enable		(const char *category_selection);
+ARV_API gboolean	arv_debug_enable		(const char *category_selection);
 
 G_END_DECLS
 
