@@ -302,7 +302,7 @@ arv_dom_node_insert_before (ArvDomNode* self, ArvDomNode* new_child, ArvDomNode*
 	}
 
 	if (ref_child_priv->parent_node != self) {
-		arv_debug_dom ("[ArvDomNode::insert_before] Ref child '%s' doesn't belong to '%s'",
+		arv_info_dom ("[ArvDomNode::insert_before] Ref child '%s' doesn't belong to '%s'",
 			   arv_dom_node_get_node_name (ref_child),
 			   arv_dom_node_get_node_name (self));
 		g_object_unref (new_child);
@@ -310,7 +310,7 @@ arv_dom_node_insert_before (ArvDomNode* self, ArvDomNode* new_child, ArvDomNode*
 	}
 
 	if (!ARV_DOM_NODE_GET_CLASS (self)->can_append_child (self, new_child)) {
-		arv_log_dom ("[ArvDomNode::insert_before] Can't append '%s' to '%s'",
+		arv_debug_dom ("[ArvDomNode::insert_before] Can't append '%s' to '%s'",
 			   arv_dom_node_get_node_name (new_child),
 			   arv_dom_node_get_node_name (self));
 		g_object_unref (new_child);
@@ -380,7 +380,7 @@ arv_dom_node_replace_child (ArvDomNode* self, ArvDomNode* new_child, ArvDomNode*
 		arv_dom_node_remove_child (self, new_child);
 
 	if (old_child == NULL) {
-		arv_debug_dom ("[ArvDomNode::replace_child] old_child == NULL)");
+		arv_info_dom ("[ArvDomNode::replace_child] old_child == NULL)");
 		g_object_unref (new_child);
 		return NULL;
 	}
@@ -516,7 +516,7 @@ arv_dom_node_append_child (ArvDomNode* self, ArvDomNode* new_child)
 		arv_dom_node_remove_child (self, new_child);
 
 	if (!ARV_DOM_NODE_GET_CLASS (self)->can_append_child (self, new_child)) {
-		arv_log_dom ("[ArvDomNode::append_child] Can't append '%s' to '%s'",
+		arv_debug_dom ("[ArvDomNode::append_child] Can't append '%s' to '%s'",
 			       arv_dom_node_get_node_name (new_child),
 			       arv_dom_node_get_node_name (self));
 		g_object_unref (new_child);
