@@ -213,6 +213,22 @@ arv_gc_boolean_set_value (ArvGcBoolean *gc_boolean, gboolean v_boolean, GError *
 		g_propagate_error (error, local_error);
 }
 
+static ArvGcFeatureNode *
+arv_gc_boolean_get_linked_feature (ArvGcFeatureNode *gc_feature_node)
+{
+	ArvGcBoolean *gc_boolean = ARV_GC_BOOLEAN (gc_feature_node);
+	ArvGcNode *pvalue_node = NULL;
+
+	if (gc_boolean->value == NULL)
+		return NULL;
+
+	pvalue_node = arv_gc_property_node_get_linked_node (gc_boolean->value);
+	if (ARV_IS_GC_FEATURE_NODE (pvalue_node))
+		return ARV_GC_FEATURE_NODE (pvalue_node);
+
+	return NULL;
+}
+
 ArvGcNode *
 arv_gc_boolean_new (void)
 {
@@ -239,6 +255,7 @@ arv_gc_boolean_class_init (ArvGcBooleanClass *this_class)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (this_class);
 	ArvDomNodeClass *dom_node_class = ARV_DOM_NODE_CLASS (this_class);
+	ArvGcFeatureNodeClass *gc_feature_node_class = ARV_GC_FEATURE_NODE_CLASS (this_class);
 
 	parent_class = g_type_class_peek_parent (this_class);
 
@@ -246,4 +263,5 @@ arv_gc_boolean_class_init (ArvGcBooleanClass *this_class)
 	dom_node_class->get_node_name = arv_gc_boolean_get_node_name;
 	dom_node_class->post_new_child = arv_gc_boolean_post_new_child;
 	dom_node_class->pre_remove_child = arv_gc_boolean_pre_remove_child;
+	gc_feature_node_class->get_linked_feature = arv_gc_boolean_get_linked_feature;
 }
