@@ -29,7 +29,17 @@
 #include <arvgc.h>
 #include <string.h>
 
-static GObjectClass *parent_class = NULL;
+struct _ArvGcEnumEntry {
+	ArvGcFeatureNode base;
+
+	ArvGcPropertyNode *value;
+};
+
+struct _ArvGcEnumEntryClass {
+	ArvGcFeatureNodeClass parent_class;
+};
+
+G_DEFINE_TYPE (ArvGcEnumEntry, arv_gc_enum_entry, ARV_TYPE_GC_FEATURE_NODE)
 
 /* ArvDomNode implementation */
 
@@ -53,7 +63,7 @@ arv_gc_enum_entry_post_new_child (ArvDomNode *self, ArvDomNode *child)
 				node->value = property_node;
 				break;
 			default:
-				ARV_DOM_NODE_CLASS (parent_class)->post_new_child (self, child);
+				ARV_DOM_NODE_CLASS (arv_gc_enum_entry_parent_class)->post_new_child (self, child);
 				break;
 		}
 	}
@@ -110,7 +120,7 @@ arv_gc_enum_entry_init (ArvGcEnumEntry *gc_enum_entry)
 static void
 arv_gc_enum_entry_finalize (GObject *object)
 {
-	parent_class->finalize (object);
+	G_OBJECT_CLASS (arv_gc_enum_entry_parent_class)->finalize (object);
 }
 
 static void
@@ -119,12 +129,8 @@ arv_gc_enum_entry_class_init (ArvGcEnumEntryClass *this_class)
 	GObjectClass *object_class = G_OBJECT_CLASS (this_class);
 	ArvDomNodeClass *dom_node_class = ARV_DOM_NODE_CLASS (this_class);
 
-	parent_class = g_type_class_peek_parent (this_class);
-
 	object_class->finalize = arv_gc_enum_entry_finalize;
 	dom_node_class->get_node_name = arv_gc_enum_entry_get_node_name;
 	dom_node_class->post_new_child = arv_gc_enum_entry_post_new_child;
 	dom_node_class->pre_remove_child = arv_gc_integer_node_pre_remove_child;
 }
-
-G_DEFINE_TYPE (ArvGcEnumEntry, arv_gc_enum_entry, ARV_TYPE_GC_FEATURE_NODE)
