@@ -29,7 +29,17 @@
 #include <arvgc.h>
 #include <string.h>
 
-static GObjectClass *parent_class = NULL;
+struct _ArvGcGroupNode {
+	ArvGcFeatureNode base;
+
+	char *comment;
+};
+
+struct _ArvGcGroupNodeClass {
+	ArvGcFeatureNodeClass parent_class;
+};
+
+G_DEFINE_TYPE (ArvGcGroupNode, arv_gc_group_node, ARV_TYPE_GC_FEATURE_NODE)
 
 /* ArvDomNode implementation */
 
@@ -87,7 +97,7 @@ arv_gc_group_node_finalize (GObject *object)
 
 	g_free (group_node->comment);
 
-	parent_class->finalize (object);
+	G_OBJECT_CLASS (arv_gc_group_node_parent_class)->finalize (object);
 }
 
 static void
@@ -97,12 +107,8 @@ arv_gc_group_node_class_init (ArvGcGroupNodeClass *this_class)
 	ArvDomNodeClass *dom_node_class = ARV_DOM_NODE_CLASS (this_class);
 	ArvDomElementClass *dom_element_class = ARV_DOM_ELEMENT_CLASS (this_class);
 
-	parent_class = g_type_class_peek_parent (this_class);
-
 	object_class->finalize = arv_gc_group_node_finalize;
 	dom_node_class->get_node_name = arv_gc_group_node_get_node_name;
 	dom_element_class->set_attribute = arv_gc_group_node_set_attribute;
 	dom_element_class->get_attribute = arv_gc_group_node_get_attribute;
 }
-
-G_DEFINE_TYPE (ArvGcGroupNode, arv_gc_group_node, ARV_TYPE_GC_FEATURE_NODE)
