@@ -27,15 +27,16 @@
 #error "Only <arv.h> can be included directly."
 #endif
 
+#include <arvapi.h>
 #include <arvtypes.h>
 #include <arvgcfeaturenode.h>
 
 G_BEGIN_DECLS
 
 #define ARV_TYPE_GC_GROUP_NODE             (arv_gc_group_node_get_type ())
-G_DECLARE_FINAL_TYPE (ArvGcGroupNode, arv_gc_group_node, ARV, GC_GROUP_NODE, ArvGcFeatureNode)
+ARV_API G_DECLARE_FINAL_TYPE (ArvGcGroupNode, arv_gc_group_node, ARV, GC_GROUP_NODE, ArvGcFeatureNode)
 
-ArvGcNode * 	arv_gc_group_node_new 		(void);
+ARV_API ArvGcNode *		arv_gc_group_node_new		(void);
 
 G_END_DECLS
 
