@@ -29,6 +29,7 @@
 #include <arvgcfeaturenode.h>
 #include <arvgc.h>
 #include <arvmisc.h>
+#include <arvdebugprivate.h>
 
 static void
 arv_gc_integer_default_init (ArvGcIntegerInterface *gc_integer_iface)
@@ -50,6 +51,8 @@ void
 arv_gc_integer_set_value (ArvGcInteger *gc_integer, gint64 value, GError **error)
 {
 	ArvGc *genicam;
+	ArvRangeCheckPolicy policy;
+	GError *local_error = NULL;
 
 	g_return_if_fail (ARV_IS_GC_INTEGER (gc_integer));
 	g_return_if_fail (error == NULL || *error == NULL);
@@ -57,43 +60,41 @@ arv_gc_integer_set_value (ArvGcInteger *gc_integer, gint64 value, GError **error
 	genicam = arv_gc_node_get_genicam (ARV_GC_NODE (gc_integer));
 	g_return_if_fail (ARV_IS_GC (genicam));
 
-	if (arv_gc_get_range_check_policy (genicam) == ARV_RANGE_CHECK_POLICY_ENABLE) {
+	policy = arv_gc_get_range_check_policy (genicam);
+
+	if (policy != ARV_RANGE_CHECK_POLICY_DISABLE) {
 		ArvGcIntegerInterface *iface = ARV_GC_INTEGER_GET_IFACE (gc_integer);
 
 		if (iface->get_min != NULL) {
-			GError *local_error = NULL;
 			gint64 min = iface->get_min (gc_integer, &local_error);
 
-			if (local_error != NULL) {
-				g_propagate_error (error, local_error);
-				return;
-			}
-
-			if (value < min) {
-				g_set_error (error, ARV_GC_ERROR, ARV_GC_ERROR_OUT_OF_RANGE,
+			if (local_error == NULL && value < min) {
+				g_set_error (&local_error, ARV_GC_ERROR, ARV_GC_ERROR_OUT_OF_RANGE,
 					     "Value '%" G_GINT64_FORMAT "' "
-					     "of node '%s' lower than allowed minimum '%" G_GINT64_FORMAT "'",
+					     "for node '%s' lower than allowed minimum '%" G_GINT64_FORMAT "'",
 					     value, arv_gc_feature_node_get_name (ARV_GC_FEATURE_NODE (gc_integer)), min);
-				return;
 			}
 		}
 
-		if (iface->get_max != NULL) {
-			GError *local_error = NULL;
+		if (local_error == NULL && iface->get_max != NULL) {
 			gint64 max = iface->get_max (gc_integer, &local_error);
 
-			if (local_error != NULL) {
+			if (local_error == NULL && value > max) {
+				g_set_error (&local_error, ARV_GC_ERROR, ARV_GC_ERROR_OUT_OF_RANGE,
+					     "Value '%" G_GINT64_FORMAT "' "
+					     "for node '%s' greater than allowed maximum '%" G_GINT64_FORMAT "'",
+					     value, arv_gc_feature_node_get_name (ARV_GC_FEATURE_NODE (gc_integer)), max);
+			}
+		}
+
+		if (local_error != NULL) {
+			if (policy == ARV_RANGE_CHECK_POLICY_DEBUG) {
+				arv_warning_policies ("Range check (%s) ignored", local_error->message);
+			} else if (policy == ARV_RANGE_CHECK_POLICY_ENABLE) {
 				g_propagate_error (error, local_error);
 				return;
 			}
-
-			if (value > max) {
-				g_set_error (error, ARV_GC_ERROR, ARV_GC_ERROR_OUT_OF_RANGE,
-					     "Value '%" G_GINT64_FORMAT "' "
-					     "of node '%s' greater than allowed maximum '%" G_GINT64_FORMAT "'",
-					     value, arv_gc_feature_node_get_name (ARV_GC_FEATURE_NODE (gc_integer)), max);
-				return;
-			}
+			g_clear_error (&local_error);
 		}
 	}
 
