@@ -687,15 +687,15 @@ arv_gvcp_packet_debug (const ArvGvcpPacket *packet, ArvDebugLevel level)
 
 	string = arv_gvcp_packet_to_string (packet);
 	switch (level) {
-		case ARV_DEBUG_LEVEL_VERBOSE_LOG:
-			arv_verbosely_log_cp ("%s", string);
-			break;
-		case ARV_DEBUG_LEVEL_LOG:
-			arv_log_cp ("%s", string);
+		case ARV_DEBUG_LEVEL_TRACE:
+			arv_trace_cp ("%s", string);
 			break;
 		case ARV_DEBUG_LEVEL_DEBUG:
 			arv_debug_cp ("%s", string);
 			break;
+		case ARV_DEBUG_LEVEL_INFO:
+			arv_info_cp ("%s", string);
+			break;
 		case ARV_DEBUG_LEVEL_WARNING:
 			arv_warning_cp ("%s", string);
 			break;
