@@ -68,8 +68,8 @@ G_BEGIN_DECLS
 #define ARV_GVBS_DEVICE_VERSION_OFFSET			0x00000088
 #define ARV_GVBS_DEVICE_VERSION_SIZE			32
 
-#define ARV_GVBS_MANUFACTURER_INFORMATIONS_OFFSET	0x000000a8
-#define ARV_GVBS_MANUFACTURER_INFORMATIONS_SIZE		48
+#define ARV_GVBS_MANUFACTURER_INFO_OFFSET       	0x000000a8
+#define ARV_GVBS_MANUFACTURER_INFO_SIZE		        48
 
 #define ARV_GVBS_SERIAL_NUMBER_OFFSET			0x000000d8
 #define ARV_GVBS_SERIAL_NUMBER_SIZE			16
@@ -220,7 +220,7 @@ typedef enum {
 	ARV_GVCP_ERROR_WRONG_CONFIG =					0x0f,
 	ARV_GVCP_ERROR_PACKET_NOT_YET_AVAILABLE =			0x10,
 	ARV_GVCP_ERROR_PACKET_AND_PREVIOUS_REMOVED_FROM_MEMORY =	0x11,
-	ARV_GVCP_ERROR_PACKET__REMOVED_FROM_MEMORY =			0x12,
+	ARV_GVCP_ERROR_PACKET_REMOVED_FROM_MEMORY =			0x12,
 	ARV_GVCP_ERROR_NO_REFERENCE_TIME =				0x13,
 	ARV_GVCP_ERROR_PACKET_TEMPORARILY_UNAVAILABLE =			0x14,
 	ARV_GVCP_ERROR_OVERFLOW =					0x15,
