@@ -533,6 +533,7 @@ test_packet_check (ArvDevice *device,
 		   GPollFD *poll_fd,
 		   GSocket *socket,
 		   char *buffer,
+                   guint max_size,
 		   guint packet_size,
 		   gboolean is_command)
 {
@@ -552,7 +553,7 @@ test_packet_check (ArvDevice *device,
 			n_events = g_poll (poll_fd, 1, 10);
 			if (n_events != 0) {
 				arv_gpollfd_clear_one (poll_fd, socket);
-				read_count = g_socket_receive (socket, buffer, 16384, NULL, NULL);
+				read_count = g_socket_receive (socket, buffer, max_size, NULL, NULL);
 			}
 			else
 				read_count = 0;
@@ -637,7 +638,7 @@ auto_packet_size (ArvGvDevice *gv_device, gboolean exit_early, GError **error)
 
 	buffer = g_malloc (max_size);
 
-	success = test_packet_check (device, &poll_fd, socket, buffer, packet_size, is_command);
+	success = test_packet_check (device, &poll_fd, socket, buffer, max_size, packet_size, is_command);
 
 	/* When exit_early is set, the function only checks the current packet size is working.
 	 * If not, the full automatic packet size adjustment is run. */
@@ -661,7 +662,8 @@ auto_packet_size (ArvGvDevice *gv_device, gboolean exit_early, GError **error)
 
 			last_size = current_size;
 
-			success = test_packet_check (device, &poll_fd, socket, buffer, current_size, is_command);
+			success = test_packet_check (device, &poll_fd, socket, buffer, max_size, current_size,
+                                                     is_command);
 
 			if (success) {
 				packet_size = current_size;
@@ -756,8 +758,8 @@ _load_genicam (ArvGvDevice *gv_device, guint32 address, size_t  *size, GError **
 {
 	char filename[ARV_GVBS_XML_URL_SIZE];
 	char *genicam = NULL;
-	g_autofree char *scheme = NULL;
-	g_autofree char *path = NULL;
+	char *scheme = NULL;
+	char *path = NULL;
 	guint64 file_address;
 	guint64 file_size;
 
@@ -772,7 +774,7 @@ _load_genicam (ArvGvDevice *gv_device, guint32 address, size_t  *size, GError **
 
 	arv_info_device ("[GvDevice::load_genicam] xml url = '%s' at 0x%x", filename, address);
 
-	arv_parse_genicam_url (filename, ARV_GVBS_XML_URL_SIZE, &scheme, NULL, &path, NULL, NULL,
+	arv_parse_genicam_url (filename, -1, &scheme, NULL, &path, NULL, NULL,
 			       &file_address, &file_size);
 
 	if (g_ascii_strcasecmp (scheme, "file") == 0) {
@@ -859,6 +861,9 @@ _load_genicam (ArvGvDevice *gv_device, guint32 address, size_t  *size, GError **
 		g_critical ("Unkown GENICAM url scheme: '%s'", filename);
 	}
 
+	g_free (scheme);
+	g_free (path);
+
 	return genicam;
 }
 
@@ -1321,6 +1326,8 @@ arv_gv_device_constructed (GObject *object)
 	guint32 capabilities;
 	guint32 device_mode;
 
+        G_OBJECT_CLASS (arv_gv_device_parent_class)->constructed (object);
+
 	if (!G_IS_INET_ADDRESS (priv->interface_address) ||
 	    !G_IS_INET_ADDRESS (priv->device_address)) {
 		arv_device_take_init_error (ARV_DEVICE (object), g_error_new (ARV_DEVICE_ERROR, ARV_DEVICE_ERROR_INVALID_PARAMETER,
