@@ -238,15 +238,15 @@ arv_gvsp_packet_debug (const ArvGvspPacket *packet, size_t packet_size, ArvDebug
 
 	string = arv_gvsp_packet_to_string (packet, packet_size);
 	switch (level) {
-		case ARV_DEBUG_LEVEL_VERBOSE_LOG:
-			arv_verbosely_log_sp ("%s", string);
-			break;
-		case ARV_DEBUG_LEVEL_LOG:
-			arv_log_sp ("%s", string);
+		case ARV_DEBUG_LEVEL_TRACE:
+			arv_trace_sp ("%s", string);
 			break;
 		case ARV_DEBUG_LEVEL_DEBUG:
 			arv_debug_sp ("%s", string);
 			break;
+		case ARV_DEBUG_LEVEL_INFO:
+			arv_info_sp ("%s", string);
+			break;
 		case ARV_DEBUG_LEVEL_WARNING:
 			arv_warning_sp ("%s", string);
 			break;
