@@ -31,9 +31,16 @@
 #include <arvdebugprivate.h>
 #include <memory.h>
 #include <errno.h>
+
+#ifdef G_OS_WIN32
+#include <windows.h>
+#else
 #include <sched.h>
 #include <sys/time.h>
 #include <sys/types.h>
+#endif
+
+#if !defined(__APPLE__) && !defined(G_OS_WIN32)
 
 #define RTKIT_SERVICE_NAME "org.freedesktop.RealtimeKit1"
 #define RTKIT_OBJECT_PATH "/org/freedesktop/RealtimeKit1"
@@ -216,8 +223,6 @@ arv_rtkit_make_high_priority (GDBusConnection *connection, pid_t thread, int nic
 #define RLIMIT_RTTIME 15
 #endif
 
-#if !defined(__APPLE__) && !defined(G_OS_WIN32)
-
 #include <sys/resource.h>
 #include <sys/syscall.h>
 
@@ -319,12 +324,41 @@ arv_make_thread_high_priority (int nice_level)
 	return TRUE;
 }
 
+#elif defined(G_OS_WIN32)
+
+gboolean
+arv_make_thread_realtime (int priority)
+{
+	SetPriorityClass(GetCurrentProcess(), REALTIME_PRIORITY_CLASS);
+	if(!SetThreadPriority(GetCurrentThread(), THREAD_PRIORITY_TIME_CRITICAL))
+   {
+		DWORD err = GetLastError();
+		arv_warning_misc ("SetPriorityClass(..., THREAD_PRIORITY_TIME_CRITICAL) failed (%lu)", err);
+		return FALSE;
+	}
+	arv_info_misc ("Thread made realtime!");
+	return TRUE;
+}
+
+gboolean
+arv_make_thread_high_priority (int priority)
+{
+	if(!SetThreadPriority(GetCurrentThread(), THREAD_PRIORITY_HIGHEST))
+   {
+		DWORD err = GetLastError();
+		arv_warning_misc ("SetPriorityClass(..., THREAD_PRIORITY_HIGHEST) failed (%lu)", err);
+		return FALSE;
+	}
+	arv_info_misc ("Thread made high-priority!");
+	return TRUE;
+}
+
 #else
 
 gboolean
 arv_make_thread_realtime (int priority)
 {
-	arv_info_misc ("SCHED API not supported on OSX/Windows");
+	arv_info_misc ("SCHED API not supported on OSX");
 
 	return FALSE;
 }
@@ -332,7 +366,7 @@ arv_make_thread_realtime (int priority)
 gboolean
 arv_make_thread_high_priority (int nice_level)
 {
-	arv_info_misc ("RtKit not supported on OSX/Windows");
+	arv_info_misc ("RtKit not supported on OSX");
 
 	return FALSE;
 }
