@@ -23,21 +23,19 @@
 #ifndef ARV_REALTIME_PRIVATE_H
 #define ARV_REALTIME_PRIVATE_H
 
-#if !defined (ARV_H_INSIDE) && !defined (ARAVIS_COMPILATION)
-#error "Only <arv.h> can be included directly."
-#endif
-
 #include <arvrealtime.h>
 #include <gio/gio.h>
 
-#ifdef G_OS_WIN32
+#ifndef G_OS_WIN32
+
 #include <unistd.h> /* for pid_t */
-#endif
 
-int 		arv_rtkit_get_max_realtime_priority	(GDBusConnection *connection, GError **error);
-int 		arv_rtkit_get_min_nice_level 		(GDBusConnection *connection, GError **error);
-gint64		arv_rtkit_get_rttime_usec_max 		(GDBusConnection *connection, GError **error);
-void		arv_rtkit_make_realtime 		(GDBusConnection *connection, pid_t thread, int priority, GError **error);
-void		arv_rtkit_make_high_priority 		(GDBusConnection *connection, pid_t thread, int nice_level, GError **error);
+/* private, but used by tests */
+ARV_API int		arv_rtkit_get_max_realtime_priority	(GDBusConnection *connection, GError **error);
+ARV_API int		arv_rtkit_get_min_nice_level 		(GDBusConnection *connection, GError **error);
+ARV_API gint64		arv_rtkit_get_rttime_usec_max 		(GDBusConnection *connection, GError **error);
+ARV_API void		arv_rtkit_make_realtime 		(GDBusConnection *connection, pid_t thread, int priority, GError **error);
+ARV_API void		arv_rtkit_make_high_priority 		(GDBusConnection *connection, pid_t thread, int nice_level, GError **error);
 
 #endif
+#endif
