@@ -231,12 +231,12 @@ arv_uvcp_packet_debug (const ArvUvcpPacket *packet, ArvDebugLevel level)
 
 	string = arv_uvcp_packet_to_string (packet);
 	switch (level) {
-		case ARV_DEBUG_LEVEL_LOG:
-			arv_log_cp ("%s", string);
-			break;
 		case ARV_DEBUG_LEVEL_DEBUG:
 			arv_debug_cp ("%s", string);
 			break;
+		case ARV_DEBUG_LEVEL_INFO:
+			arv_info_cp ("%s", string);
+			break;
 		case ARV_DEBUG_LEVEL_WARNING:
 			arv_warning_cp ("%s", string);
 			break;
