@@ -73,32 +73,77 @@ G_BEGIN_DECLS
 #define ARV_SBRM_CURRENT_SPEED			0x0040
 #define ARV_SBRM_RESERVED			0x0044
 
-#define ARV_SI_INFO				0x0000
-#define ARV_SI_CONTROL				0x0004
-#define ARV_SI_REQ_PAYLOAD_SIZE			0x0008
-#define ARV_SI_REQ_LEADER_SIZE			0x0010
-#define ARV_SI_REQ_TRAILER_SIZE			0x0014
-#define ARV_SI_MAX_LEADER_SIZE			0x0018
-#define ARV_SI_PAYLOAD_SIZE			0x001C
-#define ARV_SI_PAYLOAD_COUNT			0x0020
-#define ARV_SI_TRANSFER1_SIZE			0x0024
-#define ARV_SI_TRANSFER2_SIZE			0x0028
-#define ARV_SI_MAX_TRAILER_SIZE			0x002C
-#define ARV_SI_INFO_ALIGNMENT_MASK		0xFF000000
-#define ARV_SI_INFO_ALIGNMENT_SHIFT		0x0018
+#define ARV_SIRM_INFO				0x0000
+#define ARV_SIRM_CONTROL			0x0004
+#define ARV_SIRM_REQ_PAYLOAD_SIZE		0x0008
+#define ARV_SIRM_REQ_LEADER_SIZE		0x0010
+#define ARV_SIRM_REQ_TRAILER_SIZE		0x0014
+#define ARV_SIRM_MAX_LEADER_SIZE		0x0018
+#define ARV_SIRM_PAYLOAD_SIZE			0x001C
+#define ARV_SIRM_PAYLOAD_COUNT			0x0020
+#define ARV_SIRM_TRANSFER1_SIZE			0x0024
+#define ARV_SIRM_TRANSFER2_SIZE			0x0028
+#define ARV_SIRM_MAX_TRAILER_SIZE		0x002C
+#define ARV_SIRM_INFO_ALIGNMENT_MASK		0xFF000000
+#define ARV_SIRM_INFO_ALIGNMENT_SHIFT		0x0018
+
+#define ARV_SIRM_CONTROL_STREAM_ENABLE		0x00000001
 
 /**
- * ArvUvcpPacketType:
- * @ARV_UVCP_PACKET_TYPE_ERROR: error packet
- * @ARV_UVCP_PACKET_TYPE_ACK: acknowledge packet
- * @ARV_UVCP_PACKET_TYPE_CMD: command packet
+ * ArvUvcpStatus:
+ * @ARV_UCVP_STATUS_SUCCESS: success
+ * @ARV_UCVP_STATUS_NOT_IMPLEMENTED: command not implemented in the device
+ * @ARV_UCVP_STATUS_INVALID_PARAMETER: at least one command parameter of CCD or SCD is invalid or out of range
+ * @ARV_UVCP_STATUS_INVALID_ADDRESS: attempt to access a not existing register address
+ * @ARV_UVCP_STATUS_WRITE_PROTECT: attempt to write to a read only register
+ * @ARV_UVCP_STATUS_BAD_ALIGNMENT: attempt to access registers with an address which is not aligned according to the
+ * underlying technology
+ * @ARV_UVCP_STATUS_ACCESS_DENIED: attempt toread a non-readable or write a non-writable register address
+ * @ARV_UVCP_STATUS_BUSY: the command receiver is currently busy
+ * @ARV_UVCP_STATUS_MSG_TIMEOUT: timeout waiting for an acknowledge
+ * @ARV_UVCP_STATUS_INVALID_HEADER: the header of the received command is invalid. This includes CCD and SCD fields but
+ * not the command payload
+ * @ARV_UVCP_STATUS_WRONG_CONFIG: the current receiver configuration does not allow the execution of the sent command
+ * @ARV_UVCP_STATUS_ERROR: generic error
+ * @ARV_UVCP_STATUS_RESEND_NOT_SUPPORTED:
+ * @ARV_UVCP_STATUS_DSI_ENDPOINT_HALTED:
+ * @ARV_UVCP_STATUS_SI_PAYLOAD_SIZE_NOT_ALIGNED:
+ * @ARV_UVCP_STATUS_SI_REGISTERS_INCONSISTENT:
+ * @ARV_UVCP_STATUS_DATA_DISCARDED:
+ * @ARV_UVCP_STATUS_DATA_OVERRUN:
  */
 
 typedef enum {
-	ARV_UVCP_PACKET_TYPE_ERROR =		0xffff,
-	ARV_UVCP_PACKET_TYPE_ACK =		0x0000,
-	ARV_UVCP_PACKET_TYPE_CMD = 		0x4000
-} ArvUvcpPacketType;
+	ARV_UVCP_STATUS_SUCCESS					= 0x0000,
+	ARV_UVCP_STATUS_NOT_IMPLEMENTED				= 0x8001,
+	ARV_UVCP_STATUS_INVALID_PARAMETER			= 0x8002,
+	ARV_UVCP_STATUS_INVALID_ADDRESS				= 0x8003,
+	ARV_UVCP_STATUS_WRITE_PROTECT				= 0x8004,
+	ARV_UVCP_STATUS_BAD_ALIGNMENT         			= 0x8005,
+	ARV_UVCP_STATUS_ACCESS_DENIED         			= 0x8006,
+	ARV_UVCP_STATUS_BUSY                  			= 0x8007,
+	ARV_UVCP_STATUS_MSG_TIMEOUT           			= 0x800B,
+	ARV_UVCP_STATUS_INVALID_HEADER        			= 0x800E,
+	ARV_UVCP_STATUS_WRONG_CONFIG          			= 0x800F,
+	ARV_UVCP_STATUS_ERROR                 			= 0x8FFF,
+	ARV_UVCP_STATUS_RESEND_NOT_SUPPORTED        		= 0xA001,
+	ARV_UVCP_STATUS_DSI_ENDPOINT_HALTED         		= 0xA002,
+	ARV_UVCP_STATUS_SI_PAYLOAD_SIZE_NOT_ALIGNED 		= 0xA003,
+	ARV_UVCP_STATUS_SI_REGISTERS_INCONSISTENT   		= 0xA004,
+	ARV_UVCP_STATUS_DATA_DISCARDED              		= 0xA100,
+	ARV_UVCP_STATUS_DATA_OVERRUN                		= 0xA101
+} ArvUvcpStatus;
+
+/**
+ * ArvUvcpFlags:
+ * @ARV_UVCP_FLAGS_REQUEST_ACK: if set the sender requests an acknowledge packet from the command receiver
+ * @ARV_UVCP_FLAGS_COMMAND_RESEND: if set the command is sent as a retry of a previous sent that failed
+ */
+
+typedef enum {
+	ARV_UVCP_FLAGS_REQUEST_ACK				= 1 << 14,
+	ARV_UVCP_FLAGS_COMMAND_RESEND				= 1 << 15
+} ArvUvcpFlags;
 
 /**
  * ArvUvcpCommand:
@@ -116,7 +161,8 @@ typedef enum {
 	ARV_UVCP_COMMAND_WRITE_MEMORY_CMD =	0x0802,
 	ARV_UVCP_COMMAND_WRITE_MEMORY_ACK =	0x0803,
 	ARV_UVCP_COMMAND_PENDING_ACK =		0x0805,
-	ARV_UVCP_COMMAND_EVENT_CMD =		0x0c00
+	ARV_UVCP_COMMAND_EVENT_CMD =		0x0c00,
+	ARV_UVCP_COMMAND_EVENT_ACK =		0x0c01
 } ArvUvcpCommand;
 
 #pragma pack(push,1)
@@ -129,7 +175,10 @@ typedef enum {
 
 typedef struct {
 	guint32 magic;
-	guint16 packet_type;
+	union {
+		guint16 status;
+		guint16 flags;
+	};
 	guint16 command;
 	guint16 size;
 	guint16 id;
@@ -234,24 +283,40 @@ ArvUvcpPacket * 	arv_uvcp_packet_new_write_memory_cmd	(guint64 address, guint32
 								 guint16 packet_id, size_t *packet_size);
 char * 			arv_uvcp_packet_to_string 		(const ArvUvcpPacket *packet);
 void 			arv_uvcp_packet_debug 			(const ArvUvcpPacket *packet, ArvDebugLevel level);
-const char * 		arv_uvcp_packet_type_to_string 		(ArvUvcpPacketType value);
+const char * 		arv_uvcp_status_to_string 		(ArvUvcpStatus value);
 const char * 		arv_uvcp_command_to_string 		(ArvUvcpCommand value);
 
 
 /**
- * arv_uvcp_packet_get_packet_type:
+ * arv_uvcp_packet_get_status:
  * @packet: a #ArvUvcpPacket
  *
- * Return value: The #ArvUvcpPacketType code of @packet.
+ * Return value: The #ArvUvcpStatus code of @packet.
  */
 
-static inline ArvUvcpPacketType
-arv_uvcp_packet_get_packet_type (ArvUvcpPacket *packet)
+static inline ArvUvcpStatus
+arv_uvcp_packet_get_status (const ArvUvcpPacket *packet)
 {
 	if (packet == NULL)
-		return ARV_UVCP_PACKET_TYPE_ERROR;
+		return ARV_UVCP_STATUS_ERROR;
 
-	return (ArvUvcpPacketType) GUINT16_FROM_LE (packet->header.packet_type);
+	return (ArvUvcpStatus) GUINT16_FROM_LE (packet->header.status);
+}
+
+/**
+ * arv_uvcp_packet_get_flags:
+ * @packet: a #ArvUvcpFlags
+ *
+ * Return value: The #ArvUvcpFlags of @packet.
+ */
+
+static inline ArvUvcpFlags
+arv_uvcp_packet_get_flags (const ArvUvcpPacket *packet)
+{
+	if (packet == NULL)
+		return 0;
+
+	return (ArvUvcpFlags) GUINT16_FROM_LE (packet->header.flags);
 }
 
 /**
@@ -262,7 +327,7 @@ arv_uvcp_packet_get_packet_type (ArvUvcpPacket *packet)
  */
 
 static inline ArvUvcpCommand
-arv_uvcp_packet_get_command (ArvUvcpPacket *packet)
+arv_uvcp_packet_get_command (const ArvUvcpPacket *packet)
 {
 	if (packet == NULL)
 		return (ArvUvcpCommand) 0;
@@ -278,7 +343,7 @@ arv_uvcp_packet_set_packet_id (ArvUvcpPacket *packet, guint16 id)
 }
 
 static inline guint16
-arv_uvcp_packet_get_packet_id (ArvUvcpPacket *packet)
+arv_uvcp_packet_get_packet_id (const ArvUvcpPacket *packet)
 {
 	if (packet == NULL)
 		return 0;
