@@ -27,16 +27,20 @@
 #error "Only <arv.h> can be included directly."
 #endif
 
+#include <arvapi.h>
 #include <arvtypes.h>
 #include <arvdevice.h>
 
 G_BEGIN_DECLS
 
 #define ARV_TYPE_UV_DEVICE             (arv_uv_device_get_type ())
-G_DECLARE_FINAL_TYPE (ArvUvDevice, arv_uv_device, ARV, UV_DEVICE, ArvDevice)
+ARV_API G_DECLARE_FINAL_TYPE (ArvUvDevice, arv_uv_device, ARV, UV_DEVICE, ArvDevice)
 
-ArvDevice * 	arv_uv_device_new 			(const char *vendor, const char *product, const char *serial_number,
-							 GError **error);
+ARV_API ArvDevice * 	arv_uv_device_new 		(const char *vendor, const char *product,
+                                                         const char *serial_number, GError **error);
+ARV_API ArvDevice * 	arv_uv_device_new_from_guid	(const char *guid, GError **error);
+
+ARV_API void 		arv_uv_device_set_usb_mode	(ArvUvDevice *uv_device, ArvUvUsbMode usb_mode);
 
 G_END_DECLS
 
