@@ -129,12 +129,12 @@ arv_uvsp_packet_debug (const ArvUvspPacket *packet, ArvDebugLevel level)
 
 	string = arv_uvsp_packet_to_string (packet);
 	switch (level) {
-		case ARV_DEBUG_LEVEL_LOG:
-			arv_log_sp ("%s", string);
-			break;
 		case ARV_DEBUG_LEVEL_DEBUG:
 			arv_debug_sp ("%s", string);
 			break;
+		case ARV_DEBUG_LEVEL_INFO:
+			arv_info_sp ("%s", string);
+			break;
 		case ARV_DEBUG_LEVEL_WARNING:
 			arv_warning_sp ("%s", string);
 			break;
