@@ -33,7 +33,8 @@
 
 G_BEGIN_DECLS
 
-ArvStream * 	arv_uv_stream_new	(ArvUvDevice *uv_device, ArvStreamCallback callback, void *user_data, GError **error);
+ArvStream * 	arv_uv_stream_new	(ArvUvDevice *uv_device, ArvStreamCallback callback, void *user_data,
+                                         ArvUvUsbMode usb_mode, GError **error);
 
 G_END_DECLS
 
