@@ -25,6 +25,7 @@ static const ExpressionTestData expression_test_data[] = {
 	{"/evaluator/multiplication",			"2.5*4",	       		8,	FALSE,	10.0},
 	{"/evaluator/division",				"10/4",				2,	FALSE,	2.5},
 	{"/evaluator/division-float",			"10.0/4",			2,	FALSE,	2.5},
+	{"/evaluator/simple-minus", 			"-1",	 			-1, 	FALSE,	-1.0},
 	{"/evaluator/minus",				"4*-3",				-12,	FALSE,	-12.0},
 	{"/evaluator/plus",				"4*+3",				12,	FALSE,	12.0},
 	{"/evaluator/remainder",			"10%3",				1,	FALSE,	1.0},
@@ -35,13 +36,17 @@ static const ExpressionTestData expression_test_data[] = {
 	{"/evaluator/sqrt",				"SQRT(16)",			4,	TRUE,	4.0},
 	{"/evaluator/tan",				"TAN(0)",			0,	TRUE,	0.0},
 	{"/evaluator/atan",				"ATAN(0)",			0,	TRUE,	0.0},
-	{"/evaluator/exp",				"EXP(1)",			2,	TRUE,	M_E},
+	{"/evaluator/exp",				"EXP(1)",			2,	TRUE,	G_E},
 	{"/evaluator/trunc-plus",			"TRUNC(10.7)",			10,	TRUE,	10.0},
 	{"/evaluator/trunc-minus",			"TRUNC(-11.9)",			-11,	TRUE,	-11.0},
 	{"/evaluator/round-plus",			"ROUND(10.1)",			10,	TRUE,	10.0},
 	{"/evaluator/round-plus-plus",			"ROUND(10.9)",			11,	TRUE,	11.0},
 	{"/evaluator/round-minus",			"ROUND(-20.1)",			-20,	TRUE,	-20.0},
 	{"/evaluator/round-minus-minus",		"ROUND(-20.9)",			-21,	TRUE,	-21.0},
+	{"/evaluator/round-plus-with-precision",	"ROUND(10.11, 1)",		10,	TRUE,	10.1},
+	{"/evaluator/round-plus-plus-with-precision",	"ROUND(10.99, 1)",		11,	TRUE,	11.0},
+	{"/evaluator/round-minus-with-precision",	"ROUND(-20.11, 1)",		-20,	TRUE,	-20.1},
+	{"/evaluator/round-minus-minus-with-precision",	"ROUND(-20.99, 1)",		-21,	TRUE,	-21.0},
 	{"/evaluator/floor-plus",			"FLOOR(10.7)",			10,	TRUE,	10.0},
 	{"/evaluator/floor-minus",			"FLOOR(-11.9)",			-12,	TRUE,	-12.0},
 	{"/evaluator/ceil-plus",			"CEIL(10.7)",			11,	TRUE,	11.0},
@@ -326,8 +331,6 @@ main (int argc, char *argv[])
 
 	g_test_init (&argc, &argv, NULL);
 
-	arv_g_type_init ();
-
 	for (i = 0; i < G_N_ELEMENTS (expression_test_data); i++)
 		g_test_add_data_func (expression_test_data[i].test_name,
 				      &expression_test_data[i],
