@@ -3,6 +3,27 @@
 
 static ArvCamera *camera = NULL;
 
+static void
+discovery_test (void)
+{
+        int n_devices;
+        int i;
+
+        n_devices = arv_get_n_devices ();
+
+        for (i = 0; i < n_devices; i++) {
+                if (g_strcmp0 (arv_get_device_vendor (i), "Aravis") == 0 &&
+                    g_strcmp0 (arv_get_device_model (i), "Fake") == 0 &&
+                    g_strcmp0 (arv_get_device_serial_nbr (i), "GVTest") == 0 &&
+                    g_strcmp0 (arv_get_device_manufacturer_info (i), "none") == 0 &&
+                    g_strcmp0 (arv_get_device_id (i), "Aravis-Fake-GVTest") == 0 &&
+                    g_strcmp0 (arv_get_device_physical_id (i), "00:00:00:00:00:00") == 0)
+                        return;
+        }
+
+        g_assert_not_reached ();
+}
+
 static void
 register_test (void)
 {
@@ -228,12 +249,15 @@ main (int argc, char *argv[])
 
 	arv_set_fake_camera_genicam_filename (GENICAM_FILENAME);
 
-	simulator = arv_gv_fake_camera_new ("lo", "GVTest");
+	simulator = arv_gv_fake_camera_new ("127.0.0.1", "GVTest");
 	g_assert (ARV_IS_GV_FAKE_CAMERA (simulator));
 
 	camera = arv_camera_new ("Aravis-GVTest", NULL);
 	g_assert (ARV_IS_CAMERA (camera));
 
+	arv_update_device_list ();
+
+	g_test_add_func ("/fakegv/discovery", discovery_test);
 	g_test_add_func ("/fakegv/device_registers", register_test);
 	g_test_add_func ("/fakegv/acquisition", acquisition_test);
 	g_test_add_func ("/fakegv/stream", stream_test);
