@@ -2,6 +2,7 @@
 #include <arv.h>
 #include <arvstr.h>
 #include <string.h>
+#include "../src/arvmiscprivate.h"
 
 #if !ARAVIS_CHECK_VERSION (ARAVIS_MAJOR_VERSION, ARAVIS_MINOR_VERSION, ARAVIS_MICRO_VERSION)
 #error
@@ -177,6 +178,97 @@ arv_vendor_alias_lookup_test (void)
 	g_assert (alias == vendor_b);
 }
 
+struct {
+        guint64 pixel_format;
+} caps_data[] = {
+        { ARV_PIXEL_FORMAT_MONO_8 },
+        { ARV_PIXEL_FORMAT_MONO_10 },
+        { ARV_PIXEL_FORMAT_MONO_12 },
+        { ARV_PIXEL_FORMAT_MONO_12_PACKED },
+        { ARV_PIXEL_FORMAT_MONO_14 },
+        { ARV_PIXEL_FORMAT_MONO_16 },
+        { ARV_PIXEL_FORMAT_BAYER_GB_8 },
+        { ARV_PIXEL_FORMAT_BAYER_RG_8 },
+        { ARV_PIXEL_FORMAT_BAYER_GR_8 },
+        { ARV_PIXEL_FORMAT_BAYER_BG_8 },
+        { ARV_PIXEL_FORMAT_YUV_422_PACKED },
+        { ARV_PIXEL_FORMAT_YUV_422_YUYV_PACKED },
+        { ARV_PIXEL_FORMAT_CUSTOM_YUV_422_YUYV_PACKED },
+};
+
+static void
+caps_string_test (void)
+{
+        unsigned int i;
+
+        for (i = 0; i < G_N_ELEMENTS (caps_data); i++) {
+                const char *caps_string;
+
+                caps_string = arv_pixel_format_to_gst_caps_string (caps_data[i].pixel_format);
+                g_assert (caps_string != NULL);
+        }
+}
+
+struct {
+	const char *glob_pattern;
+	const char *pattern;
+} glob_patterns[] = {
+	{	"*Foo*",				"^.*Foo.*$"},
+	{	"Bar",					"^Bar$"},
+	{	"http://www.gnome.org/index.html",	"^http://www\\.gnome\\.org/index\\.html$"},
+	{	" Foo*  |  Bar*  ",			"^Foo.*$|^Bar.*$"}
+};
+
+static void
+glob_test (void)
+{
+	unsigned i;
+
+	for (i = 0; i < G_N_ELEMENTS (glob_patterns); i++) {
+		GRegex *regex;
+		const char *pattern;
+
+		regex = arv_regex_new_from_glob_pattern (glob_patterns[i].glob_pattern, TRUE);
+		g_assert (regex != NULL);
+		pattern = g_regex_get_pattern (regex);
+		g_assert_cmpstr (pattern, ==, glob_patterns[i].pattern);
+		g_regex_unref (regex);
+	}
+}
+
+struct {
+	const char *glob;
+	const char *check;
+        const char *check_caseless;
+} match_data[] = {
+	{	"Foo*",		"Foobar",       "foobar"},
+	{	"Foo*",		"Foo",          "foo"},
+	{	"*Bar",		"fooBar",       "foobar"},
+	{	"*Bar",		"Bar",          "bar"},
+	{	"FooBar",	"FooBar",       "foobar"},
+	{	"???{Foo}*r",	"bar{Foo}bar",  "bar{foo}bar"}
+};
+
+static void
+match_test (void)
+{
+	unsigned i;
+
+	for (i = 0; i < G_N_ELEMENTS (match_data); i++) {
+		GRegex *regex;
+
+		regex = arv_regex_new_from_glob_pattern (match_data[i].glob,FALSE);
+		g_assert (regex != NULL);
+		g_assert (g_regex_match (regex, match_data[i].check, 0, NULL));
+		g_regex_unref (regex);
+
+		regex = arv_regex_new_from_glob_pattern (match_data[i].glob, TRUE);
+		g_assert (regex != NULL);
+		g_assert (g_regex_match (regex, match_data[i].check_caseless, 0, NULL));
+		g_regex_unref (regex);
+	}
+}
+
 int
 main (int argc, char *argv[])
 {
@@ -190,6 +282,10 @@ main (int argc, char *argv[])
 	g_test_add_func ("/str/arv-str-parse-double", arv_str_parse_double_test);
 	g_test_add_func ("/str/arv-str-parse-double-list", arv_str_parse_double_list_test);
 	g_test_add_func ("/misc/arv-vendor-alias-lookup", arv_vendor_alias_lookup_test);
+	g_test_add_func ("/gstreamer/caps-string", caps_string_test);
+	g_test_add_func ("/misc/globs", glob_test);
+	g_test_add_func ("/misc/matches", match_test);
+
 
 	result = g_test_run();
 
@@ -197,4 +293,3 @@ main (int argc, char *argv[])
 
 	return result;
 }
-
