@@ -24,12 +24,12 @@
 #include <gst/gst.h>
 #include <gst/app/gstappsrc.h>
 #include <gst/video/videooverlay.h>
+#include <gst/video/video.h>
 #include <arv.h>
 #include <arvdebugprivate.h>
 #include <arvviewer.h>
 #include <math.h>
 #include <memory.h>
-#include <libnotify/notify.h>
 #ifdef GDK_WINDOWING_X11
 #include <gdk/gdkx.h>  // for GDK_WINDOW_XID
 #endif
@@ -37,6 +37,8 @@
 #include <gdk/gdkwin32.h>  // for GDK_WINDOW_HWND
 #endif
 
+#define ARV_VIEWER_NOTIFICATION_TIMEOUT 10
+
 static gboolean has_autovideo_sink = FALSE;
 static gboolean has_gtksink = FALSE;
 static gboolean has_gtkglsink = FALSE;
@@ -131,6 +133,7 @@ struct  _ArvViewer {
 	GstElement *pipeline;
 	GstElement *appsrc;
 	GstElement *transform;
+        GstElement *videosink;
 
 	guint rotation;
 	gboolean flip_vertical;
@@ -138,8 +141,6 @@ struct  _ArvViewer {
 
 	double exposure_min, exposure_max;
 
-	NotifyNotification *notification;
-
 	GtkWidget *main_window;
 	GtkWidget *main_stack;
 	GtkWidget *main_headerbar;
@@ -167,20 +168,33 @@ struct  _ArvViewer {
 	GtkWidget *trigger_combo_box;
 	GtkWidget *frame_rate_entry;
 	GtkWidget *exposure_spin_button;
-	GtkWidget *gain_spin_button;
 	GtkWidget *exposure_hscale;
-	GtkWidget *gain_hscale;
 	GtkWidget *auto_exposure_toggle;
+	GtkWidget *gain_spin_button;
+	GtkWidget *gain_hscale;
 	GtkWidget *auto_gain_toggle;
+	GtkWidget *black_level_spin_button;
+	GtkWidget *black_level_hscale;
+        GtkWidget *auto_black_level_toggle;
 	GtkWidget *acquisition_button;
 
+        GtkWidget *notification_revealer;
+        GtkWidget *notification_label;
+        GtkWidget *notification_details;
+        GtkWidget *notification_dismiss;
+
+        guint notification_timeout;
+
 	gulong camera_selected;
 	gulong exposure_spin_changed;
-	gulong gain_spin_changed;
 	gulong exposure_hscale_changed;
+	gulong auto_exposure_clicked;
+	gulong gain_spin_changed;
 	gulong gain_hscale_changed;
 	gulong auto_gain_clicked;
-	gulong auto_exposure_clicked;
+	gulong black_level_spin_changed;
+	gulong black_level_hscale_changed;
+	gulong auto_black_level_clicked;
 	gulong camera_x_changed;
 	gulong camera_y_changed;
 	gulong camera_binning_x_changed;
@@ -190,22 +204,22 @@ struct  _ArvViewer {
 	gulong pixel_format_changed;
 
 	guint gain_update_event;
+	guint black_level_update_event;
 	guint exposure_update_event;
 
 	guint status_bar_update_event;
 	gint64 last_status_bar_update_time_ms;
-	unsigned last_n_images;
-	unsigned last_n_bytes;
-	unsigned n_images;
-	unsigned n_bytes;
-	unsigned n_errors;
+	guint64 last_n_images;
+	guint64 last_n_bytes;
 
 	gboolean auto_socket_buffer;
 	gboolean packet_resend;
+	guint initial_packet_timeout;
 	guint packet_timeout;
 	guint frame_retention;
 	ArvRegisterCachePolicy register_cache_policy;
 	ArvRangeCheckPolicy range_check_policy;
+        ArvUvUsbMode usb_mode;
 
 	gulong video_window_xid;
 };
@@ -225,19 +239,23 @@ void
 arv_viewer_set_options (ArvViewer *viewer,
 			gboolean auto_socket_buffer,
 			gboolean packet_resend,
+			guint initial_packet_timeout,
 			guint packet_timeout,
 			guint frame_retention,
 			ArvRegisterCachePolicy register_cache_policy,
-			ArvRangeCheckPolicy range_check_policy)
+			ArvRangeCheckPolicy range_check_policy,
+                        ArvUvUsbMode usb_mode)
 {
 	g_return_if_fail (viewer != NULL);
 
 	viewer->auto_socket_buffer = auto_socket_buffer;
 	viewer->packet_resend = packet_resend;
+	viewer->initial_packet_timeout = initial_packet_timeout;
 	viewer->packet_timeout = packet_timeout;
 	viewer->frame_retention = frame_retention;
 	viewer->register_cache_policy = register_cache_policy;
 	viewer->range_check_policy = range_check_policy;
+        viewer->usb_mode = usb_mode;
 }
 
 static double
@@ -266,6 +284,51 @@ arv_viewer_value_from_log (double value, double min, double max)
 	return pow (10.0, (value * (log10 (max) - log10 (min)) + log10 (min)));
 }
 
+static void
+notification_dismiss_clicked_cb (GtkButton *dismiss, ArvViewer *viewer)
+{
+        if (viewer->notification_timeout > 0)
+                g_source_remove (viewer->notification_timeout);
+
+        gtk_revealer_set_reveal_child (GTK_REVEALER (viewer->notification_revealer), FALSE);
+
+        viewer->notification_timeout = 0;
+}
+
+static gboolean
+hide_notification (gpointer user_data)
+{
+        ArvViewer *viewer = user_data;
+
+        gtk_revealer_set_reveal_child (GTK_REVEALER (viewer->notification_revealer), FALSE);
+        viewer->notification_timeout = 0;
+
+        return G_SOURCE_REMOVE;
+}
+
+static void
+arv_viewer_show_notification (ArvViewer *viewer, const char *message, const char *details)
+{
+        g_return_if_fail (ARV_IS_VIEWER (viewer));
+        g_return_if_fail (message != NULL);
+
+        if (viewer->notification_timeout > 0)
+                g_source_remove (viewer->notification_timeout);
+
+        gtk_revealer_set_reveal_child (GTK_REVEALER (viewer->notification_revealer), FALSE);
+        gtk_label_set_text (GTK_LABEL (viewer->notification_label), message);
+        if (details != NULL) {
+                g_autofree char *text = g_strdup_printf ("<small>%s</small>", details);
+                gtk_widget_show (viewer->notification_details);
+                gtk_label_set_markup (GTK_LABEL (viewer->notification_details), text);
+        } else {
+                gtk_widget_hide (viewer->notification_details);
+        }
+        gtk_revealer_set_reveal_child (GTK_REVEALER (viewer->notification_revealer), TRUE);
+
+        viewer->notification_timeout = g_timeout_add_seconds (ARV_VIEWER_NOTIFICATION_TIMEOUT, hide_notification, viewer);
+}
+
 typedef struct {
 	GWeakRef stream;
 	ArvBuffer* arv_buffer;
@@ -365,13 +428,9 @@ new_buffer_cb (ArvStream *stream, ArvViewer *viewer)
 		viewer->last_buffer = g_object_ref( arv_buffer );
 
 		gst_app_src_push_buffer (GST_APP_SRC (viewer->appsrc), arv_to_gst_buffer (arv_buffer, stream));
-
-		viewer->n_images++;
-		viewer->n_bytes += size;
 	} else {
 		arv_debug_viewer ("push discarded buffer");
 		arv_stream_push_buffer (stream, arv_buffer);
-		viewer->n_errors++;
 	}
 }
 
@@ -437,6 +496,19 @@ gain_spin_cb (GtkSpinButton *spin_button, ArvViewer *viewer)
 	g_signal_handler_unblock (viewer->gain_hscale, viewer->gain_hscale_changed);
 }
 
+static void
+black_level_spin_cb (GtkSpinButton *spin_button, ArvViewer *viewer)
+{
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (viewer->auto_black_level_toggle), FALSE);
+
+	arv_camera_set_black_level (viewer->camera, gtk_spin_button_get_value (spin_button), NULL);
+
+	g_signal_handler_block (viewer->black_level_hscale, viewer->black_level_hscale_changed);
+	gtk_range_set_value (GTK_RANGE (viewer->black_level_hscale), gtk_spin_button_get_value (spin_button));
+	gtk_widget_grab_focus (GTK_WIDGET (spin_button));
+	g_signal_handler_unblock (viewer->black_level_hscale, viewer->black_level_hscale_changed);
+}
+
 static void
 exposure_scale_cb (GtkRange *range, ArvViewer *viewer)
 {
@@ -464,6 +536,18 @@ gain_scale_cb (GtkRange *range, ArvViewer *viewer)
 	g_signal_handler_unblock (viewer->gain_spin_button, viewer->gain_spin_changed);
 }
 
+static void
+black_level_scale_cb (GtkRange *range, ArvViewer *viewer)
+{
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (viewer->auto_black_level_toggle), FALSE);
+
+	arv_camera_set_black_level (viewer->camera, gtk_range_get_value (range), NULL);
+
+	g_signal_handler_block (viewer->black_level_spin_button, viewer->black_level_spin_changed);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (viewer->black_level_spin_button), gtk_range_get_value (range));
+	g_signal_handler_unblock (viewer->black_level_spin_button, viewer->black_level_spin_changed);
+}
+
 static gboolean
 update_exposure_cb (void *data)
 {
@@ -554,18 +638,69 @@ auto_gain_cb (GtkToggleButton *toggle, ArvViewer *viewer)
 	update_gain_ui (viewer, is_auto);
 }
 
+static gboolean
+update_black_level_cb (void *data)
+{
+	ArvViewer *viewer = data;
+	double black_level;
+
+	black_level = arv_camera_get_black_level (viewer->camera, NULL);
+
+	g_signal_handler_block (viewer->black_level_hscale, viewer->black_level_hscale_changed);
+	g_signal_handler_block (viewer->black_level_spin_button, viewer->black_level_spin_changed);
+	gtk_range_set_value (GTK_RANGE (viewer->black_level_hscale), black_level);
+	gtk_spin_button_set_value (GTK_SPIN_BUTTON (viewer->black_level_spin_button), black_level);
+	g_signal_handler_unblock (viewer->black_level_spin_button, viewer->black_level_spin_changed);
+	g_signal_handler_unblock (viewer->black_level_hscale, viewer->black_level_hscale_changed);
+
+	return TRUE;
+}
+
+static void
+update_black_level_ui (ArvViewer *viewer, gboolean is_auto)
+{
+	update_black_level_cb (viewer);
+
+	if (viewer->black_level_update_event > 0) {
+		g_source_remove (viewer->black_level_update_event);
+		viewer->black_level_update_event = 0;
+	}
+
+	if (is_auto)
+		viewer->black_level_update_event = g_timeout_add_seconds (1, update_black_level_cb, viewer);
+
+}
+
+
+static void
+auto_black_level_cb (GtkToggleButton *toggle, ArvViewer *viewer)
+{
+	gboolean is_auto;
+
+	is_auto = gtk_toggle_button_get_active (toggle);
+
+	arv_camera_set_black_level_auto (viewer->camera, is_auto ? ARV_AUTO_CONTINUOUS : ARV_AUTO_OFF, NULL);
+	update_black_level_ui (viewer, is_auto);
+}
+
 static void
 set_camera_widgets(ArvViewer *viewer)
 {
 	g_autofree char *string;
-	double gain_min, gain_max;
 	gboolean is_frame_rate_available;
+	double gain_min, gain_max;
 	gboolean is_gain_available;
+	gboolean auto_gain;
+	double black_level_min, black_level_max;
+	gboolean is_black_level_available;
+	gboolean auto_black_level;
 	gboolean is_exposure_available;
-	gboolean auto_gain, auto_exposure;
+        gboolean auto_exposure;
 
 	g_signal_handler_block (viewer->gain_hscale, viewer->gain_hscale_changed);
 	g_signal_handler_block (viewer->gain_spin_button, viewer->gain_spin_changed);
+	g_signal_handler_block (viewer->black_level_hscale, viewer->black_level_hscale_changed);
+	g_signal_handler_block (viewer->black_level_spin_button, viewer->black_level_spin_changed);
 	g_signal_handler_block (viewer->exposure_hscale, viewer->exposure_hscale_changed);
 	g_signal_handler_block (viewer->exposure_spin_button, viewer->exposure_spin_changed);
 
@@ -573,12 +708,18 @@ set_camera_widgets(ArvViewer *viewer)
 	gtk_spin_button_set_range (GTK_SPIN_BUTTON (viewer->exposure_spin_button),
 				   viewer->exposure_min, viewer->exposure_max);
 	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (viewer->exposure_spin_button), 200.0, 1000.0);
+
 	arv_camera_get_gain_bounds (viewer->camera, &gain_min, &gain_max, NULL);
 	gtk_spin_button_set_range (GTK_SPIN_BUTTON (viewer->gain_spin_button), gain_min, gain_max);
 	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (viewer->gain_spin_button), 1, 10);
 
+	arv_camera_get_black_level_bounds (viewer->camera, &black_level_min, &black_level_max, NULL);
+	gtk_spin_button_set_range (GTK_SPIN_BUTTON (viewer->black_level_spin_button), black_level_min, black_level_max);
+	gtk_spin_button_set_increments (GTK_SPIN_BUTTON (viewer->black_level_spin_button), 1, 10);
+
 	gtk_range_set_range (GTK_RANGE (viewer->exposure_hscale), 0.0, 1.0);
 	gtk_range_set_range (GTK_RANGE (viewer->gain_hscale), gain_min, gain_max);
+	gtk_range_set_range (GTK_RANGE (viewer->black_level_hscale), black_level_min, black_level_max);
 
 	is_frame_rate_available = arv_camera_is_frame_rate_available (viewer->camera, NULL);
 	gtk_widget_set_sensitive (viewer->frame_rate_entry, is_frame_rate_available);
@@ -590,40 +731,84 @@ set_camera_widgets(ArvViewer *viewer)
 	gtk_widget_set_sensitive (viewer->gain_hscale, is_gain_available);
 	gtk_widget_set_sensitive (viewer->gain_spin_button, is_gain_available);
 
+	is_black_level_available = arv_camera_is_black_level_available (viewer->camera, NULL);
+	gtk_widget_set_sensitive (viewer->black_level_hscale, is_black_level_available);
+	gtk_widget_set_sensitive (viewer->black_level_spin_button, is_black_level_available);
+
 	is_exposure_available = arv_camera_is_exposure_time_available (viewer->camera, NULL);
 	gtk_widget_set_sensitive (viewer->exposure_hscale, is_exposure_available);
 	gtk_widget_set_sensitive (viewer->exposure_spin_button, is_exposure_available);
 
 	g_signal_handler_unblock (viewer->gain_hscale, viewer->gain_hscale_changed);
 	g_signal_handler_unblock (viewer->gain_spin_button, viewer->gain_spin_changed);
+	g_signal_handler_unblock (viewer->black_level_hscale, viewer->black_level_hscale_changed);
+	g_signal_handler_unblock (viewer->black_level_spin_button, viewer->black_level_spin_changed);
 	g_signal_handler_unblock (viewer->exposure_hscale, viewer->exposure_hscale_changed);
 	g_signal_handler_unblock (viewer->exposure_spin_button, viewer->exposure_spin_changed);
 
 	auto_gain = arv_camera_get_gain_auto (viewer->camera, NULL) != ARV_AUTO_OFF;
+	auto_black_level = arv_camera_get_black_level_auto (viewer->camera, NULL) != ARV_AUTO_OFF;
 	auto_exposure = arv_camera_get_exposure_time_auto (viewer->camera, NULL) != ARV_AUTO_OFF;
 
 	update_gain_ui (viewer, auto_gain);
+	update_black_level_ui (viewer, auto_black_level);
 	update_exposure_ui (viewer, auto_exposure);
 
 	g_signal_handler_block (viewer->auto_gain_toggle, viewer->auto_gain_clicked);
+	g_signal_handler_block (viewer->auto_black_level_toggle, viewer->auto_black_level_clicked);
 	g_signal_handler_block (viewer->auto_exposure_toggle, viewer->auto_exposure_clicked);
 
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (viewer->auto_gain_toggle), auto_gain);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (viewer->auto_black_level_toggle), auto_black_level);
 	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (viewer->auto_exposure_toggle), auto_exposure);
 
 	gtk_widget_set_sensitive (viewer->auto_gain_toggle,
 		arv_camera_is_gain_auto_available (viewer->camera, NULL));
+	gtk_widget_set_sensitive (viewer->auto_black_level_toggle,
+		arv_camera_is_black_level_auto_available (viewer->camera, NULL));
 	gtk_widget_set_sensitive (viewer->auto_exposure_toggle,
 		arv_camera_is_exposure_auto_available (viewer->camera, NULL));
 
 	g_signal_handler_unblock (viewer->auto_gain_toggle, viewer->auto_gain_clicked);
+	g_signal_handler_unblock (viewer->auto_black_level_toggle, viewer->auto_black_level_clicked);
 	g_signal_handler_unblock (viewer->auto_exposure_toggle, viewer->auto_exposure_clicked);
 }
 
+static gboolean
+_save_gst_sample_to_file (GstSample *sample, const char *path, const char *mime_type, GError **error)
+{
+        GstSample *converted;
+        GstCaps *caps;
+        GstBuffer *gst_buffer;
+        gboolean success = FALSE;
+
+        g_return_val_if_fail (GST_IS_SAMPLE (sample), FALSE);
+
+        caps = gst_caps_from_string (mime_type);
+        converted = gst_video_convert_sample (sample, caps, GST_CLOCK_TIME_NONE, NULL);
+        gst_caps_unref (caps);
+
+        gst_buffer = gst_sample_get_buffer (converted);
+        if (gst_buffer) {
+                GstMapInfo map;
+
+                gst_buffer_map (gst_buffer, &map, GST_MAP_READ);
+                success = g_file_set_contents (path, (void *) map.data, map.size, error);
+                gst_buffer_unmap (gst_buffer, &map);
+        } else
+        gst_sample_unref (converted);
+
+        return success;
+}
+
 static void
 snapshot_cb (GtkButton *button, ArvViewer *viewer)
 {
-	GFile *file;
+        GtkFileFilter *filter;
+        GtkFileFilter *filter_all;
+        GtkWidget *dialog;
+        GstSample *sample = NULL;
+        ArvBuffer *buffer = NULL;
 	char *path;
 	char *filename;
 	GDateTime *date;
@@ -632,20 +817,23 @@ snapshot_cb (GtkButton *button, ArvViewer *viewer)
 	const char *data;
 	const char *pixel_format;
 	size_t size;
+        gint result;
+
+        if (GST_IS_ELEMENT (viewer->videosink))
+                sample = gst_base_sink_get_last_sample (GST_BASE_SINK (viewer->videosink));
+        if (ARV_IS_BUFFER (viewer->last_buffer))
+                buffer = g_object_ref (viewer->last_buffer);
+
+        if (!ARV_IS_BUFFER (buffer) && !GST_IS_SAMPLE (sample)) {
+                arv_viewer_show_notification (viewer, "No buffer available", NULL);
+                return;
+        }
 
 	g_return_if_fail (ARV_IS_CAMERA (viewer->camera));
-	g_return_if_fail (ARV_IS_BUFFER (viewer->last_buffer));
 
 	pixel_format = arv_camera_get_pixel_format_as_string (viewer->camera, NULL);
-	arv_buffer_get_image_region (viewer->last_buffer, NULL, NULL, &width, &height);
-	data = arv_buffer_get_data (viewer->last_buffer, &size);
-
-	path = g_build_filename (g_get_user_special_dir (G_USER_DIRECTORY_PICTURES),
-					 "Aravis", NULL);
-	file = g_file_new_for_path (path);
-	g_free (path);
-	g_file_make_directory (file, NULL, NULL);
-	g_object_unref (file);
+	arv_buffer_get_image_region (buffer, NULL, NULL, &width, &height);
+	data = arv_buffer_get_data (buffer, &size);
 
 	date = g_date_time_new_now_local ();
 	date_string = g_date_time_format (date, "%Y-%m-%d-%H:%M:%S");
@@ -656,22 +844,80 @@ snapshot_cb (GtkButton *button, ArvViewer *viewer)
 				    height,
 				    pixel_format != NULL ? pixel_format : "Unknown",
 				    date_string);
-	path = g_build_filename (g_get_user_special_dir (G_USER_DIRECTORY_PICTURES),
-				 "Aravis", filename, NULL);
-	g_file_set_contents (path, data, size, NULL);
+	g_free (date_string);
+	g_date_time_unref (date);
 
-	if (viewer->notification) {
-		notify_notification_update (viewer->notification,
-					    "Snapshot saved to Image folder",
-					    path,
-					    "gtk-save");
-		notify_notification_show (viewer->notification, NULL);
-	}
+	path = g_build_filename (g_get_user_special_dir (G_USER_DIRECTORY_PICTURES), filename, NULL);
+
+        dialog = gtk_file_chooser_dialog_new ("Save Snapshot", GTK_WINDOW (viewer->main_window),
+                                              GTK_FILE_CHOOSER_ACTION_SAVE,
+                                              "_Cancel",
+                                              GTK_RESPONSE_CANCEL,
+                                              "_Save",
+                                              GTK_RESPONSE_ACCEPT,
+                                              NULL);
+        gtk_file_chooser_set_do_overwrite_confirmation (GTK_FILE_CHOOSER (dialog), TRUE);
+        gtk_file_chooser_set_filename (GTK_FILE_CHOOSER (dialog), path);
+        gtk_file_chooser_set_current_name (GTK_FILE_CHOOSER (dialog), filename);
+
+        filter_all = gtk_file_filter_new ();
+        gtk_file_filter_set_name (filter_all, "Supported image formats");
+
+        if (GST_IS_SAMPLE (sample)) {
+                filter = gtk_file_filter_new ();
+                gtk_file_filter_add_mime_type (filter, "image/png");
+                gtk_file_filter_add_mime_type (filter_all, "image/png");
+                gtk_file_filter_set_name (filter, "PNG (*.png)");
+                gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
+
+                filter = gtk_file_filter_new ();
+                gtk_file_filter_add_mime_type (filter, "image/jpeg");
+                gtk_file_filter_add_mime_type (filter_all, "image/jpeg");
+                gtk_file_filter_set_name (filter, "JPEG (*.jpeg)");
+                gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
+        }
+
+        if (ARV_IS_BUFFER (buffer)) {
+                filter = gtk_file_filter_new ();
+                gtk_file_filter_add_pattern (filter, "*.raw");
+                gtk_file_filter_add_pattern (filter_all, "*.raw");
+                gtk_file_filter_set_name (filter, "Raw images (*.raw)");
+                gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter);
+        }
+
+        gtk_file_chooser_add_filter (GTK_FILE_CHOOSER (dialog), filter_all);
+        gtk_file_chooser_set_filter (GTK_FILE_CHOOSER (dialog), filter_all);
 
 	g_free (path);
 	g_free (filename);
-	g_free (date_string);
-	g_date_time_unref (date);
+
+        result = gtk_dialog_run (GTK_DIALOG (dialog));
+        if (result == GTK_RESPONSE_ACCEPT) {
+                g_autoptr (GError) error = NULL;
+                g_autofree char * content_type = NULL;
+                gboolean success = FALSE;
+
+                filename = gtk_file_chooser_get_filename (GTK_FILE_CHOOSER (dialog));
+
+                content_type = g_content_type_guess (filename, NULL, 0, NULL);
+
+                if (GST_IS_SAMPLE (sample) && g_content_type_is_mime_type (content_type, "image/png")) {
+                        success = _save_gst_sample_to_file (sample, filename, "image/png", NULL);
+                } else if (GST_IS_SAMPLE (sample) && g_content_type_is_mime_type (content_type, "image/jpeg")) {
+                        success = _save_gst_sample_to_file (sample, filename, "image/jpeg", NULL);
+                } else if (ARV_IS_BUFFER (buffer)) {
+                        success = g_file_set_contents (filename, data, size, &error);
+                        g_free (filename);
+                }
+
+                if (!success)
+                        arv_viewer_show_notification (viewer, "Failed to save image to file",
+                                                      error != NULL ? error->message : NULL);
+        }
+
+        gtk_widget_destroy (dialog);
+        g_clear_pointer (&sample, gst_sample_unref);
+        g_clear_object (&buffer);
 }
 
 static void
@@ -729,9 +975,9 @@ update_status_bar_cb (void *data)
 	char *text;
 	gint64 time_ms = g_get_real_time () / 1000;
 	gint64 elapsed_time_ms = time_ms - viewer->last_status_bar_update_time_ms;
-	guint n_images = viewer->n_images;
-	guint n_bytes = viewer->n_bytes;
-	guint n_errors = viewer->n_errors;
+	guint64 n_images = arv_stream_get_info_uint64_by_name (viewer->stream, "n_completed_buffers");
+	guint64 n_bytes = arv_stream_get_info_uint64_by_name (viewer->stream, "n_transferred_bytes");
+	guint64 n_errors = arv_stream_get_info_uint64_by_name (viewer->stream, "n_failures");
 
 	if (elapsed_time_ms == 0)
 		return TRUE;
@@ -742,7 +988,7 @@ update_status_bar_cb (void *data)
 	gtk_label_set_label (GTK_LABEL (viewer->fps_label), text);
 	g_free (text);
 
-	text = g_strdup_printf ("%u image%s / %u error%s",
+	text = g_strdup_printf ("%" G_GUINT64_FORMAT " image%s / %" G_GUINT64_FORMAT " error%s",
 				n_images, n_images > 0 ? "s" : "",
 				n_errors, n_errors > 0 ? "s" : "");
 	gtk_label_set_label (GTK_LABEL (viewer->image_label), text);
@@ -931,6 +1177,11 @@ stop_video (ArvViewer *viewer)
 		g_source_remove (viewer->gain_update_event);
 		viewer->gain_update_event = 0;
 	}
+
+	if (viewer->black_level_update_event > 0) {
+		g_source_remove (viewer->black_level_update_event);
+		viewer->black_level_update_event = 0;
+	}
 }
 
 static GstBusSyncReply
@@ -959,7 +1210,6 @@ static gboolean
 start_video (ArvViewer *viewer)
 {
 	GstElement *videoconvert;
-	GstElement *videosink;
 	GstCaps *caps;
 	ArvPixelFormat pixel_format;
 	unsigned payload;
@@ -991,6 +1241,7 @@ start_video (ArvViewer *viewer)
 				      "packet-resend", ARV_GV_STREAM_PACKET_RESEND_NEVER,
 				      NULL);
 		g_object_set (viewer->stream,
+			      "initial-packet-timeout", (unsigned) viewer->initial_packet_timeout * 1000,
 			      "packet-timeout", (unsigned) viewer->packet_timeout * 1000,
 			      "frame-retention", (unsigned) viewer->frame_retention * 1000,
 			      NULL);
@@ -1005,13 +1256,17 @@ start_video (ArvViewer *viewer)
 	pixel_format = arv_camera_get_pixel_format (viewer->camera, NULL);
 
 	caps_string = arv_pixel_format_to_gst_caps_string (pixel_format);
-	if (caps_string == NULL ||
-	    (g_str_has_prefix (caps_string, "video/x-bayer") && !has_bayer2rgb)) {
-		g_message ("GStreamer cannot understand the camera pixel format: 0x%x!\n", (int) pixel_format);
+	if (caps_string == NULL) {
+		g_message ("GStreamer cannot understand this camera pixel format: 0x%x!", (int) pixel_format);
+		stop_video (viewer);
+		return FALSE;
+        } else if (g_str_has_prefix (caps_string, "video/x-bayer") && !has_bayer2rgb) {
+		g_message ("GStreamer bayer plugin is required for pixel format: 0x%x!", (int) pixel_format);
 		stop_video (viewer);
 		return FALSE;
 	}
 
+        arv_camera_set_acquisition_mode (viewer->camera, ARV_ACQUISITION_MODE_CONTINUOUS, NULL);
 	arv_camera_start_acquisition (viewer->camera, NULL);
 
 	viewer->pipeline = gst_pipeline_new ("pipeline");
@@ -1054,23 +1309,23 @@ start_video (ArvViewer *viewer)
 #else
 		{
 #endif
-			videosink = gst_element_factory_make ("gtksink", NULL);
-			gst_bin_add_many (GST_BIN (viewer->pipeline), videosink, NULL);
-			gst_element_link_many (viewer->transform, videosink, NULL);
+			viewer->videosink = gst_element_factory_make ("gtksink", NULL);
+			gst_bin_add_many (GST_BIN (viewer->pipeline), viewer->videosink, NULL);
+			gst_element_link_many (viewer->transform, viewer->videosink, NULL);
 		}
 
-		g_object_get (videosink, "widget", &video_widget, NULL);
+		g_object_get (viewer->videosink, "widget", &video_widget, NULL);
 		gtk_container_add (GTK_CONTAINER (viewer->video_frame), video_widget);
 		gtk_widget_show (video_widget);
 		g_object_set(G_OBJECT (video_widget), "force-aspect-ratio", TRUE, NULL);
 		gtk_widget_set_size_request (video_widget, 640, 480);
 	} else {
-		videosink = gst_element_factory_make ("autovideosink", NULL);
-		gst_bin_add (GST_BIN (viewer->pipeline), videosink);
-		gst_element_link_many (viewer->transform, videosink, NULL);
+		viewer->videosink = gst_element_factory_make ("autovideosink", NULL);
+		gst_bin_add (GST_BIN (viewer->pipeline), viewer->videosink);
+		gst_element_link_many (viewer->transform, viewer->videosink, NULL);
 	}
 
-	g_object_set(G_OBJECT (videosink), "sync", FALSE, NULL);
+	g_object_set(G_OBJECT (viewer->videosink), "sync", FALSE, NULL);
 
 	caps = gst_caps_from_string (caps_string);
 	arv_camera_get_region (viewer->camera, NULL, NULL, &width, &height, NULL);
@@ -1097,9 +1352,6 @@ start_video (ArvViewer *viewer)
 	viewer->last_status_bar_update_time_ms = g_get_real_time () / 1000;
 	viewer->last_n_images = 0;
 	viewer->last_n_bytes = 0;
-	viewer->n_images = 0;
-	viewer->n_bytes = 0;
-	viewer->n_errors = 0;
 	viewer->status_bar_update_event = g_timeout_add_seconds (1, update_status_bar_cb, viewer);
 
 	g_signal_connect (viewer->stream, "new-buffer", G_CALLBACK (new_buffer_cb), viewer);
@@ -1134,6 +1386,20 @@ stop_camera (ArvViewer *viewer)
 	g_clear_pointer (&viewer->camera_name, g_free);
 }
 
+static void
+set_sensitive (GtkCellLayout *cell_layout,
+               GtkCellRenderer *cell,
+               GtkTreeModel *tree_model,
+               GtkTreeIter *iter,
+               gpointer data)
+{
+        gboolean valid;
+
+        gtk_tree_model_get (tree_model, iter, 1, &valid, -1);
+
+        g_object_set(cell, "sensitive", valid, NULL);
+}
+
 static gboolean
 start_camera (ArvViewer *viewer, const char *camera_id)
 {
@@ -1144,6 +1410,8 @@ start_camera (ArvViewer *viewer, const char *camera_id)
 	const char **pixel_format_strings;
 	guint i, n_pixel_formats, n_pixel_format_strings, n_valid_formats;
 	gboolean binning_available;
+        gboolean bayer_tooltip = FALSE;
+        gint current_format = -1;
 
 	stop_camera (viewer);
 
@@ -1157,6 +1425,9 @@ start_camera (ArvViewer *viewer, const char *camera_id)
 	arv_device_set_range_check_policy (arv_camera_get_device (viewer->camera),
 					   viewer->range_check_policy);
 
+        if (arv_camera_is_uv_device (viewer->camera))
+                arv_camera_uv_set_usb_mode (viewer->camera, viewer->usb_mode);
+
 	viewer->camera_name = g_strdup (camera_id);
 
 	gtk_widget_set_sensitive (viewer->camera_parameters, TRUE);
@@ -1176,19 +1447,37 @@ start_camera (ArvViewer *viewer, const char *camera_id)
 	pixel_format_string = arv_camera_get_pixel_format_as_string (viewer->camera, NULL);
 	for (i = 0; i < n_pixel_formats; i++) {
 		const char *caps_string = arv_pixel_format_to_gst_caps_string (pixel_formats[i]);
-		if ( caps_string != NULL &&
-		    (has_bayer2rgb || !g_str_has_prefix (caps_string, "video/x-bayer"))) {
-			gtk_list_store_append (list_store, &iter);
-			gtk_list_store_set (list_store, &iter, 0, pixel_format_strings[i], -1);
-			if (g_strcmp0 (pixel_format_strings[i], pixel_format_string) == 0)
-				gtk_combo_box_set_active (GTK_COMBO_BOX (viewer->pixel_format_combo), n_valid_formats);
+                gboolean valid = FALSE;
+
+                gtk_list_store_append (list_store, &iter);
+
+                if (caps_string != NULL && g_str_has_prefix (caps_string, "video/x-bayer") && !has_bayer2rgb) {
+                        bayer_tooltip = TRUE;
+                } else if (caps_string != NULL) {
+			if (current_format < 0 ||
+                            g_strcmp0 (pixel_format_strings[i], pixel_format_string) == 0)
+                                current_format = i;
 			n_valid_formats++;
+                        valid = TRUE;
 		}
+
+                gtk_list_store_set (list_store, &iter,
+                                    0, pixel_format_strings[i],
+                                    1, valid,
+                                    -1);
 	}
 	g_free (pixel_formats);
 	g_free (pixel_format_strings);
-	gtk_widget_set_sensitive (viewer->pixel_format_combo, n_valid_formats > 1);
-	gtk_widget_set_sensitive (viewer->video_mode_button, TRUE);
+	gtk_widget_set_sensitive (viewer->pixel_format_combo, n_valid_formats > 0);
+	gtk_widget_set_sensitive (viewer->video_mode_button, n_valid_formats > 0);
+
+	gtk_combo_box_set_active (GTK_COMBO_BOX (viewer->pixel_format_combo), current_format >= 0 ? current_format : 0);
+
+        gtk_widget_set_tooltip_text (GTK_WIDGET (viewer->pixel_format_combo),
+                                     bayer_tooltip ?
+                                     "Found bayer pixel formats, but the GStreamer bayer plugin "
+                                     "is not installed." :
+                                     NULL);
 
 	binning_available = arv_camera_is_binning_available (viewer->camera, NULL);
 	gtk_widget_set_sensitive (viewer->camera_binning_x, binning_available);
@@ -1297,6 +1586,8 @@ activate (GApplication *application)
 {
 	ArvViewer *viewer = (ArvViewer *) application;
 	g_autoptr (GtkBuilder) builder;
+        g_autoptr (GtkListStore) list_store = NULL;
+        GtkCellRenderer *renderer = gtk_cell_renderer_text_new();
 
 	builder = gtk_builder_new_from_resource ("/org/aravis/viewer/arv-viewer.ui");
 
@@ -1324,16 +1615,35 @@ activate (GApplication *application)
 	viewer->trigger_combo_box = GTK_WIDGET (gtk_builder_get_object (builder, "trigger_combobox"));
 	viewer->frame_rate_entry = GTK_WIDGET (gtk_builder_get_object (builder, "frame_rate_entry"));
 	viewer->exposure_spin_button = GTK_WIDGET (gtk_builder_get_object (builder, "exposure_spinbutton"));
-	viewer->gain_spin_button = GTK_WIDGET (gtk_builder_get_object (builder, "gain_spinbutton"));
 	viewer->exposure_hscale = GTK_WIDGET (gtk_builder_get_object (builder, "exposure_hscale"));
-	viewer->gain_hscale = GTK_WIDGET (gtk_builder_get_object (builder, "gain_hscale"));
 	viewer->auto_exposure_toggle = GTK_WIDGET (gtk_builder_get_object (builder, "auto_exposure_togglebutton"));
+	viewer->gain_spin_button = GTK_WIDGET (gtk_builder_get_object (builder, "gain_spinbutton"));
+	viewer->gain_hscale = GTK_WIDGET (gtk_builder_get_object (builder, "gain_hscale"));
 	viewer->auto_gain_toggle = GTK_WIDGET (gtk_builder_get_object (builder, "auto_gain_togglebutton"));
+	viewer->black_level_spin_button = GTK_WIDGET (gtk_builder_get_object (builder, "black_level_spinbutton"));
+	viewer->black_level_hscale = GTK_WIDGET (gtk_builder_get_object (builder, "black_level_hscale"));
+	viewer->auto_black_level_toggle = GTK_WIDGET (gtk_builder_get_object (builder, "auto_black_level_togglebutton"));
 	viewer->rotate_cw_button = GTK_WIDGET (gtk_builder_get_object (builder, "rotate_cw_button"));
 	viewer->flip_vertical_toggle = GTK_WIDGET (gtk_builder_get_object (builder, "flip_vertical_togglebutton"));
 	viewer->flip_horizontal_toggle = GTK_WIDGET (gtk_builder_get_object (builder, "flip_horizontal_togglebutton"));
 	viewer->acquisition_button = GTK_WIDGET (gtk_builder_get_object (builder, "acquisition_button"));
 
+        viewer->notification_revealer = GTK_WIDGET (gtk_builder_get_object (builder, "notification_revealer"));
+        viewer->notification_label = GTK_WIDGET (gtk_builder_get_object (builder, "notification_label"));
+        viewer->notification_details = GTK_WIDGET (gtk_builder_get_object (builder, "notification_details"));
+        viewer->notification_dismiss = GTK_WIDGET (gtk_builder_get_object (builder, "notification_dismiss"));
+
+        g_signal_connect (viewer->notification_dismiss, "clicked",
+                          G_CALLBACK (notification_dismiss_clicked_cb), viewer);
+
+        list_store = gtk_list_store_new(2, G_TYPE_STRING, G_TYPE_BOOLEAN);
+        gtk_combo_box_set_model (GTK_COMBO_BOX (viewer->pixel_format_combo), GTK_TREE_MODEL (list_store));
+
+        gtk_cell_layout_clear (GTK_CELL_LAYOUT (viewer->pixel_format_combo));
+        gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (viewer->pixel_format_combo), renderer, TRUE);
+        gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (viewer->pixel_format_combo), renderer, "text", 0, NULL);
+        gtk_cell_layout_set_cell_data_func (GTK_CELL_LAYOUT (viewer->pixel_format_combo), renderer, set_sensitive, NULL, NULL);
+
 	gtk_widget_set_no_show_all (viewer->trigger_combo_box, TRUE);
 
 	gtk_widget_show_all (viewer->main_window);
@@ -1359,16 +1669,22 @@ activate (GApplication *application)
 						    G_CALLBACK (camera_selection_changed_cb), viewer);
 	viewer->exposure_spin_changed = g_signal_connect (viewer->exposure_spin_button, "value-changed",
 							  G_CALLBACK (exposure_spin_cb), viewer);
-	viewer->gain_spin_changed = g_signal_connect (viewer->gain_spin_button, "value-changed",
-						      G_CALLBACK (gain_spin_cb), viewer);
 	viewer->exposure_hscale_changed = g_signal_connect (viewer->exposure_hscale, "value-changed",
 							    G_CALLBACK (exposure_scale_cb), viewer);
-	viewer->gain_hscale_changed = g_signal_connect (viewer->gain_hscale, "value-changed",
-							G_CALLBACK (gain_scale_cb), viewer);
 	viewer->auto_exposure_clicked = g_signal_connect (viewer->auto_exposure_toggle, "clicked",
 							  G_CALLBACK (auto_exposure_cb), viewer);
+	viewer->gain_spin_changed = g_signal_connect (viewer->gain_spin_button, "value-changed",
+						      G_CALLBACK (gain_spin_cb), viewer);
+	viewer->gain_hscale_changed = g_signal_connect (viewer->gain_hscale, "value-changed",
+							G_CALLBACK (gain_scale_cb), viewer);
 	viewer->auto_gain_clicked = g_signal_connect (viewer->auto_gain_toggle, "clicked",
 						      G_CALLBACK (auto_gain_cb), viewer);
+	viewer->black_level_spin_changed = g_signal_connect (viewer->black_level_spin_button, "value-changed",
+						      G_CALLBACK (black_level_spin_cb), viewer);
+	viewer->black_level_hscale_changed = g_signal_connect (viewer->black_level_hscale, "value-changed",
+							G_CALLBACK (black_level_scale_cb), viewer);
+	viewer->auto_black_level_clicked = g_signal_connect (viewer->auto_black_level_toggle, "clicked",
+						      G_CALLBACK (auto_black_level_cb), viewer);
 	viewer->pixel_format_changed = g_signal_connect (viewer->pixel_format_combo, "changed",
 							 G_CALLBACK (pixel_format_combo_cb), viewer);
 	viewer->camera_x_changed = g_signal_connect (viewer->camera_x, "value-changed",
@@ -1408,11 +1724,7 @@ viewer_shutdown (GApplication *application)
 static void
 finalize (GObject *object)
 {
-	ArvViewer *viewer = (ArvViewer *) object;
-
 	G_OBJECT_CLASS (arv_viewer_parent_class)->finalize (object);
-
-	g_clear_object (&viewer->notification);
 }
 
 ArvViewer *
@@ -1426,7 +1738,7 @@ arv_viewer_new (void)
   g_set_application_name ("ArvViewer");
 
   arv_viewer = g_object_new (arv_viewer_get_type (),
-			     "application-id", "org.aravis.ArvViewer",
+			     "application-id", "org.aravis.Aravis",
 			     "flags", G_APPLICATION_NON_UNIQUE,
 			     "inactivity-timeout", 30000,
 			     NULL);
@@ -1438,7 +1750,6 @@ arv_viewer_new (void)
 static void
 arv_viewer_init (ArvViewer *viewer)
 {
-	viewer->notification = notify_notification_new (NULL, NULL, NULL);
 	viewer->auto_socket_buffer = FALSE;
 	viewer->packet_resend = TRUE;
 	viewer->packet_timeout = 20;
