@@ -34,9 +34,11 @@ ArvViewer * 		arv_viewer_new 			(void);
 void			arv_viewer_set_options		(ArvViewer *viewer,
 							 gboolean auto_socket_buffer,
 							 gboolean packet_resend,
+							 guint initial_packet_timeout,
 							 guint packet_timeout,
 							 guint frame_retention,
 							 ArvRegisterCachePolicy register_cache_policy,
-							 ArvRangeCheckPolicy range_check_policy);
+							 ArvRangeCheckPolicy range_check_policy,
+                                                         ArvUvUsbMode usb_mode);
 
 G_END_DECLS
