@@ -22,11 +22,11 @@
 
 #include <arvviewer.h>
 #include <arvdebugprivate.h>
+#include <arvgvstreamprivate.h>
 #include <gtk/gtk.h>
 #include <gst/gst.h>
 #include <arv.h>
 #include <stdlib.h>
-#include <libnotify/notify.h>
 #include <libintl.h>
 
 #if GST_GL_HAVE_WINDOW_X11 && defined (GDK_WINDOWING_X11)
@@ -38,8 +38,10 @@ static char *arv_option_register_cache = NULL;
 static char *arv_option_range_check = NULL;
 static gboolean arv_viewer_option_auto_socket_buffer = FALSE;
 static gboolean arv_viewer_option_no_packet_resend = FALSE;
-static unsigned int arv_viewer_option_packet_timeout = 20;
-static unsigned int arv_viewer_option_frame_retention = 100;
+static unsigned int arv_viewer_option_initial_packet_timeout = ARV_GV_STREAM_INITIAL_PACKET_TIMEOUT_US_DEFAULT / 1000;
+static unsigned int arv_viewer_option_packet_timeout = ARV_GV_STREAM_PACKET_TIMEOUT_US_DEFAULT / 1000;
+static unsigned int arv_viewer_option_frame_retention = ARV_GV_STREAM_FRAME_RETENTION_US_DEFAULT / 1000;
+static char *arv_option_uv_usb_mode = NULL;
 
 static const GOptionEntry arv_viewer_option_entries[] =
 {
@@ -51,6 +53,10 @@ static const GOptionEntry arv_viewer_option_entries[] =
 		"no-packet-resend",			'r', 0, G_OPTION_ARG_NONE,
 		&arv_viewer_option_no_packet_resend,	"No packet resend", NULL
 	},
+	{
+		"initial-packet-timeout", 		        'l', 0, G_OPTION_ARG_INT,
+		&arv_viewer_option_initial_packet_timeout, 	"Initial packet timeout (ms)", NULL
+	},
 	{
 		"packet-timeout", 			'p', 0, G_OPTION_ARG_INT,
 		&arv_viewer_option_packet_timeout, 	"Packet timeout (ms)", NULL
@@ -69,6 +75,11 @@ static const GOptionEntry arv_viewer_option_entries[] =
 		&arv_option_range_check,		"Range check policy",
 		"{disable|enable}"
 	},
+	{
+		"usb-mode",				's', 0, G_OPTION_ARG_STRING,
+		&arv_option_uv_usb_mode,		"USB device I/O mode",
+		"{sync|async}"
+	},
 	{
 		"debug", 				'd', 0, G_OPTION_ARG_STRING,
 		&arv_viewer_option_debug_domains, 	NULL,
@@ -87,6 +98,7 @@ main (int argc, char **argv)
 	GError *error = NULL;
 	ArvRegisterCachePolicy register_cache_policy;
 	ArvRangeCheckPolicy range_check_policy;
+	ArvUvUsbMode usb_mode;
 
 #if GST_GL_HAVE_WINDOW_X11 && defined(GDK_WINDOWING_X11)
 	XInitThreads ();
@@ -141,6 +153,17 @@ main (int argc, char **argv)
 		return EXIT_FAILURE;
 	}
 
+	if (arv_option_uv_usb_mode == NULL)
+		usb_mode = ARV_UV_USB_MODE_DEFAULT;
+	else if (g_strcmp0 (arv_option_uv_usb_mode, "sync") == 0)
+		usb_mode = ARV_UV_USB_MODE_SYNC;
+	else if (g_strcmp0 (arv_option_uv_usb_mode, "async") == 0)
+		usb_mode = ARV_UV_USB_MODE_ASYNC;
+	else {
+		printf ("Invalid USB device I/O mode\n");
+		return EXIT_FAILURE;
+	}
+
 	if (!arv_debug_enable (arv_viewer_option_debug_domains)) {
 		if (g_strcmp0 (arv_viewer_option_debug_domains, "help") != 0)
 			printf ("Invalid debug selection\n");
@@ -156,18 +179,16 @@ main (int argc, char **argv)
 	arv_viewer_set_options (viewer,
 				arv_viewer_option_auto_socket_buffer,
 				!arv_viewer_option_no_packet_resend,
+				arv_viewer_option_initial_packet_timeout,
 				arv_viewer_option_packet_timeout,
 				arv_viewer_option_frame_retention,
 				register_cache_policy,
-				range_check_policy);
-
-	notify_init ("Aravis Viewer");
+				range_check_policy,
+                                usb_mode);
 
 	status = g_application_run (G_APPLICATION (viewer), argc, argv);
 
 	g_object_unref (viewer);
 
-	notify_uninit ();
-
 	return status;
 }
